@@ -1,3 +1,5 @@
+from csv import DictReader
+import random
 class Nooneknowme :
     # คลาส ข้อมูลเกี่ยวกับข้อมูลที่เมคขึ้นมา
     def __init__(self):
@@ -32,6 +34,13 @@ It's just me and me and me me me!!!
 
         """
         print(picart)
+    
+    def dice2(self):
+        dice_list = [1,2,3,4,5,6]
+        firstdice = random.choice(dice_list)
+        secounddice = random.choice(dice_list)
+        print(f'ทอยเต๋าได้: {firstdice} ,{secounddice}')
+
         
 
 
@@ -40,4 +49,5 @@ if __name__ == '__main__':
     testname.show_name()
     testname.about()
     testname.picasciiart()
-    testname.playmusic()
\ No newline at end of file
+    testname.playmusic()
+    testname.dice2()
\ No newline at end of file
